@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.0900';
+our $VERSION = '0.0901';
 
 use Moo;
 use MIDI::Simple;
@@ -126,9 +126,7 @@ sub metronome34 {
     my $self = shift;
     my $bars = shift || $self->bars;
 
-    my $i = 0;
-
-    for my $n ( 1 .. $bars ) {
+    for ( 1 .. $bars ) {
         $self->note( $self->quarter, $self->ride1, $self->kick );
         $self->note( $self->quarter, $self->ride1 );
         $self->note( $self->quarter, $self->ride1, $self->snare );
@@ -155,7 +153,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.0900
+version 0.0901
 
 =head1 SYNOPSIS
 
@@ -194,7 +192,7 @@ Default: C<MIDI-Drummer.mid>
 
 =head2 score
 
-Default: MIDI::Simple->new_score
+Default: C<MIDI::Simple-E<gt>new_score>
 
 =head2 channel
 
@@ -234,7 +232,7 @@ Computed given the B<signature>.
 
 =head2 signature
 
-Default: 4/4
+Default: C<4/4>
 
 B<beats> / B<divisions>
 
